@@ -13,7 +13,7 @@ from auto_schema import runner
 
 class Postgres:
     def get_url(self, _schema_path):
-        return "postgresql://localhost/autoschema_test"
+        return os.getenv("DB_CONNECTION_STRING", "postgresql://localhost/autoschema_test")
 
     def get_finalizer(self, metadata, session, connection, transaction, engine):
         def fn():
@@ -128,6 +128,23 @@ def metadata_with_table():
     return metadata_with_base_table_restored()
 
 
+def metadata_with_cols_added_to_table(metadata):
+    changes = default_children_of_table()
+
+    changes.append(
+        sa.Column('rainbow', sa.Text(), nullable=True),
+    )
+    changes.append(
+        sa.Column('new_column', sa.Integer(), nullable=True)
+    )
+    metadata = sa.MetaData()
+    sa.Table('accounts', metadata,
+             *changes,
+             )
+
+    return metadata
+
+
 def metadata_with_base_table_restored():
     metadata = sa.MetaData()
     changes = default_children_of_table()
@@ -211,6 +228,32 @@ def metadata_table_with_timetz():
     return metadata
 
 
+@pytest.fixture
+def metadata_with_arrays():
+    metadata = sa.MetaData()
+    sa.Table("tbl", metadata,
+             sa.Column('string_list', postgresql.ARRAY(
+                 sa.Text), nullable=False),
+             sa.Column('string_list_2', postgresql.ARRAY(
+                 sa.Text()), nullable=False),
+             sa.Column('int_list', postgresql.ARRAY(
+                 sa.Integer), nullable=False),
+             sa.Column('bool_list', postgresql.ARRAY(
+                 sa.Boolean), nullable=False),
+             sa.Column('date_list', postgresql.ARRAY(sa.Date), nullable=False),
+             sa.Column('time_list', postgresql.ARRAY(sa.Time), nullable=False),
+             sa.Column('timetz_list', postgresql.ARRAY(
+                 sa.Time(timezone=True)), nullable=False),
+             sa.Column('timestamp_list', postgresql.ARRAY(
+                 sa.TIMESTAMP), nullable=False),
+             sa.Column('timestamptz_list', postgresql.ARRAY(
+                 sa.TIMESTAMP(timezone=True)), nullable=False),
+             sa.Column('float_list', postgresql.ARRAY(
+                 sa.Float), nullable=False)
+             )
+    return metadata
+
+
 def identity_metadata_func(metadata):
     return metadata
 
